aboutsummaryrefslogtreecommitdiffstats
path: root/apps
diff options
context:
space:
mode:
Diffstat (limited to 'apps')
-rw-r--r--apps/user_ldap/lib/User/User.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/apps/user_ldap/lib/User/User.php b/apps/user_ldap/lib/User/User.php
index 635c0df6dfe..214b475e2e4 100644
--- a/apps/user_ldap/lib/User/User.php
+++ b/apps/user_ldap/lib/User/User.php
@@ -739,8 +739,8 @@ class User {
}
- //make sure it is a square and not bigger than 128x128
- $size = min([$this->image->width(), $this->image->height(), 128]);
+ //make sure it is a square and not bigger than 512x512
+ $size = min([$this->image->width(), $this->image->height(), 512]);
if (!$this->image->centerCrop($size)) {
$this->logger->error('croping image for avatar failed for '.$this->dn, ['app' => 'user_ldap']);
return false;